import * as projectActions from '../actions/project-actions';
import * as viewer2DActions from '../actions/viewer2d-actions';
import * as viewer3DActions from '../actions/viewer3d-actions';
import * as linesActions from '../actions/lines-actions';
import * as holesActions from '../actions/holes-actions';
import * as sceneActions from '../actions/scene-actions';
import * as verticesActions from '../actions/vertices-actions';
import * as itemsActions from '../actions/items-actions';
import * as areaActions from '../actions/area-actions';

export default {
  projectActions,
  viewer2DActions,
  viewer3DActions,
  linesActions,
  holesActions,
  sceneActions,
  verticesActions,
  itemsActions,
  areaActions
}
